# runtime

Recording lifecycle, monitoring, and device management.

::: omgrab.runtime.recording_manager

::: omgrab.runtime.recording_session

::: omgrab.runtime.network_monitor

::: omgrab.runtime.device_status

::: omgrab.runtime.battery_monitor

::: omgrab.runtime.gpio_manager

::: omgrab.runtime.wifi_connect
